=====
Inigo
=====

    *"Let me explain. No, there is too much. Let me sum up." ~ Inigo Montoya*

Inigos are simple sequences which experience loss of information with time.
They are append-only and grow logarithmically in size with their input,
instead of linearly, discarding information as they grow.

License
=======

Inigo is available under the MIT/X11 license; see ``LICENSE`` for details.

Credits
=======

The name of the library and data structure goes to Allen Short, who also
provided the classic movie quote.

David Barbour's explanation of the possible uses of inigos inspired me to
provide a Python implementation. His article is at
http://awelonblue.wordpress.com/2013/01/24/exponential-decay-of-history-improved/
and is worth reading.
